@@ -16,6 +16,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/**
+ * SECTION: gva-common
+ * @short_description: Common Definitions
+ **/
+
 #ifndef GVA_COMMON_H
 #define GVA_COMMON_H
 
@@ -30,8 +35,10 @@
 
 #include <sqlite3.h>
 #include <gconf/gconf-client.h>
+#include "gconf-bridge.h"		/* Embedded in GVA */
 
 #define GVA_GCONF_PREFIX                "/apps/" PACKAGE
+#define GVA_GCONF_ALL_COLUMNS_KEY       GVA_GCONF_PREFIX "/all-columns"
 #define GVA_GCONF_AUTO_SAVE_KEY         GVA_GCONF_PREFIX "/auto-save"
 #define GVA_GCONF_COLUMNS_KEY           GVA_GCONF_PREFIX "/columns"
 #define GVA_GCONF_FAVORITES_KEY         GVA_GCONF_PREFIX "/favorites"
@@ -40,11 +47,14 @@
 #define GVA_GCONF_SELECTED_VIEW_KEY     GVA_GCONF_PREFIX "/selected-view"
 #define GVA_GCONF_SORT_COLUMN_KEY       GVA_GCONF_PREFIX "/sort-column"
 #define GVA_GCONF_VERSION_KEY           GVA_GCONF_PREFIX "/version"
+#define GVA_GCONF_WINDOW_PREFIX         GVA_GCONF_PREFIX "/window"
 
 G_BEGIN_DECLS
 
 /* Command Line Options */
 extern gboolean opt_build_database;
+extern gboolean opt_version;
+extern gboolean opt_which_emulator;
 
 G_END_DECLS
 
