@@ -19,6 +19,9 @@
 /**
  * SECTION: gva-ui
  * @short_description: User Interface Support
+ *
+ * These functions and macros provide easy access to global actions and
+ * widgets in the application.
  **/
 
 #ifndef GVA_UI_H
@@ -40,6 +43,7 @@
 #define GVA_ACTION_QUIT                 (gva_ui_get_action ("quit"))
 #define GVA_ACTION_RECORD               (gva_ui_get_action ("record"))
 #define GVA_ACTION_REMOVE_FAVORITE      (gva_ui_get_action ("remove-favorite"))
+#define GVA_ACTION_SEARCH               (gva_ui_get_action ("search"))
 #define GVA_ACTION_SHOW_PLAY_BACK       (gva_ui_get_action ("show-play-back"))
 #define GVA_ACTION_START                (gva_ui_get_action ("start"))
 #define GVA_ACTION_VIEW_AVAILABLE       (gva_ui_get_action ("view-available"))
@@ -104,6 +108,10 @@
 #define GVA_WIDGET_PROPERTIES_WINDOW \
         (gva_ui_get_widget ("properties-window"))
 
+/* Search Window */
+#define GVA_WIDGET_SEARCH_WINDOW \
+        (gva_ui_get_widget ("search-window"))
+
 G_BEGIN_DECLS
 
 GtkAction *     gva_ui_get_action               (const gchar *action_name);
