@@ -32,16 +32,16 @@
 #include "gva-properties.h"
 #include "gva-ui.h"
 
-/* Command Line Options */
-gboolean opt_build_database;
-gboolean opt_which_emulator;
-
 static GOptionEntry entries[] =
 {
         { "build-database", 'b', 0,
           G_OPTION_ARG_NONE, &opt_build_database,
           N_("Build the games database"), NULL },
 
+        { "version", 'v', 0,
+          G_OPTION_ARG_NONE, &opt_version,
+          N_("Show the application version"), NULL },
+
         { "which-emulator", 'w', 0,
           G_OPTION_ARG_NONE, &opt_which_emulator,
           N_("Show which emulator will be used"), NULL },
@@ -49,7 +49,7 @@ static GOptionEntry entries[] =
         { NULL }
 };
 
-static gboolean
+static void
 start (void)
 {
         GvaProcess *process = NULL;
@@ -83,24 +83,23 @@ start (void)
                 g_object_unref (process);
 
                 if (main_loop_quit)
-                        return FALSE;
+                        return;
         }
 
         gtk_action_set_sensitive (GVA_ACTION_VIEW_AVAILABLE, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_FAVORITES, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_VIEW_RESULTS, TRUE);
 
+	gconf_bridge_bind_property (
+		gconf_bridge_get (), GVA_GCONF_SELECTED_VIEW_KEY,
+		G_OBJECT (GVA_ACTION_VIEW_AVAILABLE), "current-value");
+
         /* Force a tree view update. */
-        last_view = gva_tree_view_get_last_selected_view ();
-        if (last_view == gva_tree_view_get_selected_view ())
+        if (gva_tree_view_get_selected_view () == 0)
         {
                 gva_tree_view_update (&error);
                 gva_error_handle (&error);
         }
-        else
-                gva_tree_view_set_selected_view (last_view);
-
-        return FALSE;
 }
 
 gint
@@ -108,10 +107,9 @@ main (gint argc, gchar **argv)
 {
         GError *error = NULL;
 
-        /* initialize locale data */
-        setlocale (LC_ALL, "");
-        bindtextdomain (PACKAGE, LOCALEDIR);
-        textdomain (PACKAGE);
+        bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        textdomain (GETTEXT_PACKAGE);
 
         g_thread_init (NULL);
 
@@ -120,6 +118,12 @@ main (gint argc, gchar **argv)
         if (error != NULL)
                 g_error ("%s", error->message);
 
+        if (opt_version)
+        {
+                g_print ("%s\n", PACKAGE_STRING);
+                exit (0);
+        }
+
         if (opt_which_emulator)
         {
                 g_print ("%s\n", MAME_PROGRAM);
@@ -141,7 +145,7 @@ main (gint argc, gchar **argv)
         gva_error_handle (&error);
 #endif
 
-        g_idle_add ((GSourceFunc) start, NULL);
+        gtk_init_add ((GtkFunction) start, NULL);
 
         gtk_main ();
 
